/*
 * Copyright (c) 2006-2021, RT-Thread Development Team
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Change Logs:
 * Date           Author       Notes
 * 2021-12-20     张植皓       the first version
 */
#include <rtthread.h>
#include <rtdevice.h>
#include "board.h"
#include "task.h"
#define ADC_DEV_NAME        "adc0"      /* ADC 设备名称 */
#define ADC_DEV_CHANNEL      0          /* ADC 通道 */
#define BAT_2                3          /* ADC 通道 */
#define BAT_1                7          /* ADC 通道 */
#define REFER_VOLTAGE       330         /* 参考电压 3.3V,数据精度乘以100保留2位小数*/
#define CONVERT_BITS        (1 << 10)   /* 转换位数为12位 */

static rt_thread_t dynamic_thread = RT_NULL;//动态线程控制块指针
void BAT_VOL_SCAN(void *parameter);         //电池电压扫描线程
//线程结构体数组(适合线程动态创建)
static TaskStruct TaskThreads[] = {
    {"BAT_VOL_SCAN", BAT_VOL_SCAN, RT_NULL, 1024, 10, 10},
    {"",RT_NULL, RT_NULL,RT_NULL,RT_NULL,RT_NULL}
};


rt_adc_device_t adc_dev;
rt_uint32_t value, vol;
rt_err_t ret = RT_EOK;

void AdcTask_Init(void)
{
    rt_uint8_t TaskThreadIndex = 0;

    rt_adc_device_t adc_dev;
    /* 查找设备 */
    adc_dev = (rt_adc_device_t)rt_device_find(ADC_DEV_NAME);
    if (adc_dev == RT_NULL)
    {
        rt_kprintf("rt_device_find() run failed! can't find %s device!\n", ADC_DEV_NAME);
        return RT_ERROR;
    }
    /* 使能设备 */
    rt_adc_enable(adc_dev, BAT_1);
    rt_adc_enable(adc_dev, BAT_2);
    while(1)
    {
        if(rt_strcmp(TaskThreads[TaskThreadIndex].name,"") != 0)
        {

            dynamic_thread = rt_thread_create(TaskThreads[TaskThreadIndex].name,       // 线程名字
                                              TaskThreads[TaskThreadIndex].entry,      // 线程入口函数
                                              TaskThreads[TaskThreadIndex].parameter,  // 线程入口函数参数
                                              TaskThreads[TaskThreadIndex].stack_size, // 线程栈大小
                                              TaskThreads[TaskThreadIndex].priority,   // 线程的优先级
                                              TaskThreads[TaskThreadIndex].tick        // 线程时间片
                            );
            if(dynamic_thread != RT_NULL)
            {
               rt_thread_startup(dynamic_thread);
            }
            else
            {
                rt_kprintf("adc_task_create failed!\r\n");
            }
            TaskThreadIndex ++;
         }
         else
             break;
     }
}
INIT_APP_EXPORT(AdcTask_Init);


extern uint8_t k2;
extern uint8_t k1;
extern uint8_t bat2_1;
extern uint8_t bat1_1;
extern uint8_t bat2_2;
extern uint8_t bat1_2;
void BAT_VOL_SCAN(void *parameter)
{
    while(1){
        value = rt_adc_read(adc_dev, BAT_1);
//        rt_kprintf("the BAT_1 is :%d \n", value);
        if (value < 1000) {
            rt_pin_write(k1, PIN_LOW);
        }
        value = rt_adc_read(adc_dev, BAT_2);
//        rt_kprintf("the BAT_2 is :%d \n", value);
        if (value < 1000) {
            rt_pin_write(k2, PIN_LOW);
        }
        rt_thread_mdelay(2000);
    }
}
