/*
 * Copyright (c) 2006-2021, RT-Thread Development Team
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Change Logs:
 * Date           Author       Notes
 * 2021-12-20     张植皓       the first version
 */
#include <rtthread.h>
#include <rtdevice.h>
#include "board.h"
#include "task.h"
uint8_t led;
uint8_t k2;
uint8_t k1;
uint8_t c2;
uint8_t c1;
uint8_t d2;
uint8_t d1;
uint8_t bat2_1;
uint8_t bat1_1;
uint8_t bat2_2;
uint8_t bat1_2;

static rt_thread_t dynamic_thread = RT_NULL;//动态线程控制块指针
void POWER_INPUT_SCAN(void *parameter);         //电池电压扫描线程
//线程结构体数组(适合线程动态创建)
static TaskStruct TaskThreads[] = {
    {"POWER_INPUT_SCAN", POWER_INPUT_SCAN, RT_NULL, 1024, 10, 10},
    {"",RT_NULL, RT_NULL,RT_NULL,RT_NULL,RT_NULL}
};
static int my_gpio_set(void)
{
    led = rt_pin_get("PE.1");
    k2 = rt_pin_get("PA.6");
    k1 = rt_pin_get("PE.4");
    c2 = rt_pin_get("PA.0");
    c1 = rt_pin_get("PA.2");
    d2 = rt_pin_get("PF.0");
    d1 = rt_pin_get("PA.5");
    bat2_1 = rt_pin_get("PB.0");
    bat1_1 = rt_pin_get("PE.5");
    bat2_2 = rt_pin_get("PB.1");
    bat1_2 = rt_pin_get("PE.6");
    rt_pin_mode(led, PIN_MODE_OUTPUT);
    rt_pin_mode(k2, PIN_MODE_OUTPUT);
    rt_pin_mode(k1, PIN_MODE_OUTPUT);
    rt_pin_mode(c2, PIN_MODE_INPUT);
    rt_pin_mode(c1, PIN_MODE_INPUT);
    rt_pin_mode(d2, PIN_MODE_INPUT);
    rt_pin_mode(d1, PIN_MODE_INPUT);
    rt_pin_mode(bat2_1, PIN_MODE_INPUT);
    rt_pin_mode(bat1_1, PIN_MODE_INPUT);
    rt_pin_mode(bat2_2, PIN_MODE_INPUT);
    rt_pin_mode(bat1_2, PIN_MODE_INPUT);
    rt_pin_write(k2, PIN_HIGH);
    rt_pin_write(k1, PIN_HIGH);
    return 0;
}
INIT_BOARD_EXPORT(my_gpio_set);

void POWER_INPUT_Task_Init(void)
{
    rt_uint8_t TaskThreadIndex = 0;
    while(1)
    {
        if(rt_strcmp(TaskThreads[TaskThreadIndex].name,"") != 0)
        {

            dynamic_thread = rt_thread_create(TaskThreads[TaskThreadIndex].name,       // 线程名字
                                              TaskThreads[TaskThreadIndex].entry,      // 线程入口函数
                                              TaskThreads[TaskThreadIndex].parameter,  // 线程入口函数参数
                                              TaskThreads[TaskThreadIndex].stack_size, // 线程栈大小
                                              TaskThreads[TaskThreadIndex].priority,   // 线程的优先级
                                              TaskThreads[TaskThreadIndex].tick        // 线程时间片
                            );
            if(dynamic_thread != RT_NULL)
            {
               rt_thread_startup(dynamic_thread);
            }
            else
            {
                rt_kprintf("POWER_INPUT_Task_create failed!\r\n");
            }
            TaskThreadIndex ++;
         }
         else
             break;
     }
}
INIT_APP_EXPORT(POWER_INPUT_Task_Init);


extern uint8_t d2;
extern uint8_t d1;
extern uint8_t c1;
extern uint8_t c2;
//当电池未充满时关闭升压通道。ps：可改为电池电压低于某个值时关闭升压通道，让adc线程和输入检测线程合并
void POWER_INPUT_SCAN(void *parameter)
{
    while(1){
        if (rt_pin_read(d1)) {
            rt_pin_write(k1, PIN_LOW);
            rt_kprintf("BAT_1 is charging or waiting for charge.\n");
        }
        else {
            rt_pin_write(k1, PIN_HIGH);
            rt_kprintf("BAT_1 done!\n");
        }
        if (rt_pin_read(d2)) {
            rt_pin_write(k2, PIN_LOW);
            rt_kprintf("BAT_2 is charging or waiting for charge.\n");
        }
        else {
            rt_pin_write(k2, PIN_HIGH);
            rt_kprintf("BAT_2 done!\n");
        }
        rt_thread_mdelay(2000);
    }
}




